#!/bin/bash
set -e -o xtrace

# Set up a virtualenv.
VIRTUALENV=venv-$(hostname)
if [[ -e $VIRTUALENV ]]
then
  source $VIRTUALENV/bin/activate
else
  trap 'rm -rf $VIRTUALENV' EXIT
  python3 -m venv $VIRTUALENV
  source $VIRTUALENV/bin/activate
  pip install -U pip wheel
  trap '' EXIT
fi

# Log some information about the current machine.
hostname
python -V | grep 'Python 3\.[78]'

# Install the current version of the package and its dependencies.
pip install .

# Synchronize data.
if [[ $(hostname) = aura.fi.muni.cz || $(hostname) = adonis.fi.muni.cz ]]
then
  rsync --delete --progress -Cavz aurora:/nlp/projekty/ahisto/public_html/dokumenty/ /var/tmp/xnovot32/dokumenty_copy
  rsync --delete --progress -Cavz aurora:/nlp/projekty/ahisto/public_html/ocr-output/ /var/tmp/xnovot32/ocr-output_copy
elif [[ $(hostname) = mir ]]
then
  rsync --delete --progress -Cavz aurora:/nlp/projekty/ahisto/public_html/dokumenty/ /home/novotny/ahisto-named-entity-search-files/dokumenty_copy
  rsync --delete --progress -Cavz aurora:/nlp/projekty/ahisto/public_html/ocr-output/ /home/novotny/ahisto-named-entity-search-files/ocr-output_copy
fi

# Remove previous results.
if [[ $(hostname) = apollo.fi.muni.cz ]]
then
  pushd /nlp/projekty/ahisto/public_html/named-entity-search
  rm -rf results/
  mkdir results/
  cp -av results_2022-03-03T17+01:00_45e4dfb/annotations.xlsx results/
  cp -av results_2022-03-03T17+01:00_45e4dfb/patchset-persons.xlsx results/
  cp -av results_2022-03-03T17+01:00_45e4dfb/patchset-places.xlsx results/
  START_TIME=$(date --iso-8601=hours)
  HUMAN_READABLE_START_TIME="$(date +'%-d. %-m. %Y')"
  echo 'Now you can start computing the results on other machines'
  popd
fi

# Compute the results.
if [[ $(hostname) = adonis.fi.muni.cz ]]
then
  systemd-run --user --scope -p MemoryMax=250G nice -n 10 python scripts/02b_find_all_entities.py
elif [[ $(hostname) = aura.fi.muni.cz ]]
then
  systemd-run --user --scope -p MemoryMax=1T nice -n 10 python scripts/02b_find_all_entities.py
else
  nice -n 10 python scripts/02b_find_all_entities.py
fi
